#include "IZ_input.h"

void IZ_InputHandleSDLEvents(SDL_Event e, IZ_InputState* state) {
	IZ_JoystickHandleEvents(e, &state->joystick_state, &state->action);
	IZ_KeyboardHandleEvents(e, &state->keyboard_state, &state->action);
}

void IZ_InputHandlePortMIDIEvents(PmEvent e, IZ_InputState* state) {
	IZ_MIDIInputHandleEvents(e, &state->midi_input_state, &state->action);
}

void IZ_InputInitialize(const char* config_path, IZ_InputState* state) {
	*state = (IZ_InputState) {
		.action = {},
		.joystick_state = {},
		.midi_input_state = {},
		.keyboard_state = {},
	};

	IZ_ProcedureResult joystick_result = IZ_JoystickInitialize(config_path, &state->joystick_state);
	if (joystick_result) {
		fprintf_s(stderr, "Error committing joystick config. Code: %u.\n", joystick_result);
	}

	IZ_ProcedureResult keyboard_result = IZ_KeyboardInitialize(config_path, &state->keyboard_state);
	if (keyboard_result) {
		fprintf_s(stderr, "Error committing keyboard config. Code: %u.\n", keyboard_result);
	}

	IZ_ProcedureResult midi_input_result = IZ_MIDIInputInitialize(config_path, &state->midi_input_state);
	if (midi_input_result) {
		fprintf_s(stderr, "Error committing MIDI input config. Code: %u.\n", midi_input_result);
	}

	u8 player_index;
	for (player_index = 0; player_index < PLAYERS; player_index += 1) {
		state->action[player_index] = 0;
	}
}

void IZ_InputTeardown(IZ_InputState* state) {
	IZ_JoystickTeardown(&state->joystick_state);
	IZ_MIDIInputTeardown(&state->midi_input_state);
}
